summaryrefslogtreecommitdiff
path: root/tinyusb/host/ehci/ehci.c
diff options
context:
space:
mode:
Diffstat (limited to 'tinyusb/host/ehci/ehci.c')
-rw-r--r--tinyusb/host/ehci/ehci.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/tinyusb/host/ehci/ehci.c b/tinyusb/host/ehci/ehci.c
index f0a69b6a2..e24548bc1 100644
--- a/tinyusb/host/ehci/ehci.c
+++ b/tinyusb/host/ehci/ehci.c
@@ -166,8 +166,8 @@ void async_advance_isr(ehci_qhd_t * const async_head)
p_control_qhd->used = 0;
p_control_qhd->p_qtd_list_head = p_control_qhd->p_qtd_list_tail = NULL;
- // TODO abstract: Host Controller has cleaned up its data for this device, notify usbh
- usbh_device_hcd_data_cleaned_up_cb(relative_dev_addr+1);
+ // Host Controller has cleaned up its cached data for this device, set state to unplug
+ usbh_device_info_pool[relative_dev_addr+1].state = TUSB_DEVICE_STATE_UNPLUG;
}
// check if any other endpoints in pool is removing